from database_connectors.oracle_connector import OracleConnector
from database_connectors.postgres_connector import PostgresConnector
from database_connectors.sql_server_connector import SqlServerConnector


class ConnectorFactory():
    """Helper class that provides a standard way to create a Data Checker using factory method"""
    
    def __init__(self):
        pass
    
    def create_connector(self, connector_type, connector_settings):

        if connector_type == 'sqlserver':
            connector = SqlServerConnector(connector_settings["host"], connector_settings["user"],
                                           connector_settings["password"],connector_settings["port"],
                                           connector_settings["database"])
            return connector

        elif connector_type == 'postgres':
            connector = PostgresConnector(connector_settings["host"], connector_settings["user"],
                                          connector_settings["password"], connector_settings["port"],
                                          connector_settings["database"])
            return connector
        elif connector_type == 'oracledb':
            connector = OracleConnector(**connector_settings)
            return connector
    
    


from setuptools import setup, find_packages

setup(
    name='cmr_connectors_lib',
    version='0.2',
    packages=find_packages(),
    # Add dependencies here
    install_requires=[
    "libkrb5-dev",
    "libsasl2-dev",
    "pymssql",
    "pyodbc",
    "psycopg2",
    "sqlalchemy",
    "cx_oracle"
    ],
    description='CMR Connectors Library',
    author='Soufiane',
    author_email='soufiane.amghar@berexia.com',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
